Official interfaces for ST components.

Dependents:   X_NUCLEO_IKS01A1 mDot_X_NUCLEO_IKS01A1 53L0A1 X_NUCLEO_IKS01A1 ... more

Fork of ST_INTERFACES by Davide Aliprandi

This library contains all abstract classes which together constitute the common API to which all existing and future ST components will adhere to.

Revision:
4:8f70f7159316
Parent:
3:b1bb477e115e
--- a/Sensors/LightSensor.h	Fri Mar 10 10:50:53 2017 +0100
+++ b/Sensors/LightSensor.h	Fri Mar 10 11:03:17 2017 +0100
@@ -58,10 +58,10 @@
 
     /**
      * @brief       Get current light [lux]
      * @param[out]  piData Pointer to where to store light to
      * @return      0 in case of success, an error code otherwise
      */
-    virtual int get_lux(uint32_t *piData) = 0;
+    virtual int get_lux(uint32_t *pi_data) = 0;
 
     /**
      * @brief Destructor.
@@ -58,10 +58,10 @@
     /**
      * @brief       Get current light [lux]
-     * @param[out]  piData Pointer to where to store light to
+     * @param[out]  pi_data Pointer to where to store light to
      * @return      0 in case of success, an error code otherwise
      */